@@ -116,6 +116,13 @@ def load():
                 message = "ERROR (Введенные данные указаны неверно)"
 
                 return render_template("message.html", message=message, url=url)
+        else:
+
+            url = 'load'
+            message = "ERROR (Неверный формат файла)"
+
+            return render_template("message.html", message=message, url=url)
+
 
     else:
         return render_template("load.html")
